command

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 9, 2021 License: MIT Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Builder added in v0.3.0

type Builder struct {
	// contains filtered or unexported fields
}

func (*Builder) Clone added in v0.3.0

func (b *Builder) Clone() error

Clone either clone the project from a git repository either copy it from a local folder to a temporary folder. It doesn't remove the temporary folder, it is the caller's responsibility to remove the directory when no longer needed.

func (*Builder) ParseSubConfigSpecs added in v0.3.0

func (b *Builder) ParseSubConfigSpecs(cmd string) error

ParseSubconfigSpecs will look for bobconfig file inside the template itself and parse it if found

func (*Builder) ProcessBuild added in v0.3.0

func (b *Builder) ProcessBuild(path *widgets.TextField) error

ProcessBuild clones the template and replace all the actionable items to the files contents, files names and directory names recursively.

type Command

type Command struct {
	ConfigApp config.App
	Screen    *ui.Screen
}

func (Command) Build

func (c Command) Build(args ...string)

func (Command) BuildMenu added in v0.3.0

func (c Command) BuildMenu(args ...string)

func (Command) Help added in v0.3.0

func (c Command) Help(args ...string)

func (Command) Init

func (c Command) Init(_ ...string)

func (Command) MainMenu added in v0.3.0

func (c Command) MainMenu(args ...string)

Jump to