Discover Packages
github.com/jcalmat/bob
pkg
config
package
Version:
v0.3.0
Opens a new window with list of versions in this module.
Published: May 9, 2021
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Command struct {
Description string `yaml:"description" json:"description"`
Path string `yaml:"path" json:"path"`
Git string `yaml:"git" json:"git"`
Specs `yaml:",inline" json:",inline"`
}
type GitSettings struct {
SSH SSHGitSettings `yaml:"ssh" json:"ssh"`
}
type Item struct {
Name string
Value interface{}
}
type SSHGitSettings struct {
PrivateKeyFile string `yaml:"privateKeyFile" json:"privateKeyFile"`
PrivateKeyPassword string `yaml:"privateKeyPassword" json:"privateKeyPassword"`
}
type Settings struct {
Git GitSettings `yaml:"git" json:"git"`
}
type Specs struct {
Variables []Variable `yaml:"vars" json:"vars"`
Skip []string `yaml:"skip" json:"skip"`
}
const (
String Type = "string"
Array Type = "array"
Bool Type = "bool"
)
type Variable struct {
Name string `yaml:"name" json:"name"`
Type Type `yaml:"type" json:"type"`
Format *string `yaml:"format,omitempty" json:"format,omitempty"`
Dependencies []Variable `yaml:"deps" json:"deps"`
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.