Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Builder ¶ added in v0.3.0
type Builder struct {
// contains filtered or unexported fields
}
func (*Builder) Clone ¶ added in v0.3.0
Clone either clone the project from a git repository either copy it from a local folder to a temporary folder. It doesn't remove the temporary folder, it is the caller's responsibility to remove the directory when no longer needed.
func (*Builder) ParseSubConfigSpecs ¶ added in v0.3.0
ParseSubconfigSpecs will look for bobconfig file inside the template itself and parse it if found
Click to show internal directories.
Click to hide internal directories.